Runtime handle for an Exograph index.
The handle keeps the Postgres candidate retrieval, fragment storage, and tree access modules together for query execution.
@type t() :: %Exograph.Index{ fragment_store: term(), fragment_store_backend: module(), inverted: term(), inverted_backend: module(), tree_store: term() | nil, tree_store_backend: module() | nil }